searchData={"items":[{"type":"module","title":"Orderly","doc":"`Orderly` provides sorted set and sorted map implementations based on Erlang's\n[`gb_sets`](https://www.erlang.org/doc/man/gb_sets) and\n[`gb_trees`](https://www.erlang.org/doc/man/gb_trees).\n\nSee the modules `Orderly.SortedMap` and `Orderly.SortedSet` for\nspecific documentation.","ref":"Orderly.html"},{"type":"module","title":"Orderly.SortedMap","doc":"Implementation of a sorted map based on Erlang's\n[`gb_trees`](https://www.erlang.org/doc/man/gb_trees).\n\n`SortedMap` has many of the core functions found in\n[`Map`](https://hexdocs.pm/elixir/1.16.2/Map.html). The important difference\nbetween `SortedMap` and `Map` is that the keys in a sorted\nmap have a defined order, specifically the\n[Erlang term order](https://www.erlang.org/doc/reference_manual/expressions#term-comparisons).\nFor example:\n\n    map =\n      [b: 2, a: 1, c: 3, a: 4]\n      |> SortedMap.new()\n      |> SortedMap.to_list()\n    #=> [a: 4, b: 2, c: 3]\n\nAll functions that involve accessing, inserting, or deleting a key have\n`O(log n)` time complexity.\n\nUnlike `Map`, `SortedMap` is an opaque data structure that does not support\npattern matching.\n\n`SortedMap` implements the `Enumerable` protocol, so that `Enum`\nfunctions can be applied to sorted maps. When applying `Stream` functions\nto a sorted map, it is recommended to first create a stream using\n`SortedMap.to_stream/1` or `SortedMap.to_stream/2`, which adapts the effecient\nlazy iterator pattern provided by `gb_trees`.","ref":"Orderly.SortedMap.html"},{"type":"function","title":"Orderly.SortedMap.delete/2","doc":"Delete the key-value pair for the given `key` in `sorted_map`.\n\nIf `key` is not present, the map is returned unchanged.","ref":"Orderly.SortedMap.html#delete/2"},{"type":"function","title":"Examples - Orderly.SortedMap.delete/2","doc":"iex> map = Orderly.SortedMap.new([a: 1])\n    iex> Orderly.SortedMap.delete(map, :a)\n    Orderly.SortedMap.new([])\n    iex> Orderly.SortedMap.delete(map, :b)\n    Orderly.SortedMap.new([a: 1])","ref":"Orderly.SortedMap.html#delete/2-examples"},{"type":"function","title":"Orderly.SortedMap.equal?/2","doc":"","ref":"Orderly.SortedMap.html#equal?/2"},{"type":"function","title":"Orderly.SortedMap.fetch/2","doc":"Fetch the value for the given `key` in `sorted_map`.\n\nThis returns `{:ok, value}` if the `key` is present, and `:error` otherwise.","ref":"Orderly.SortedMap.html#fetch/2"},{"type":"function","title":"Examples - Orderly.SortedMap.fetch/2","doc":"iex> map = Orderly.SortedMap.new([a: 1])\n    iex> Orderly.SortedMap.fetch(map, :a)\n    {:ok, 1}\n    iex> Orderly.SortedMap.fetch(map, :b)\n    :error","ref":"Orderly.SortedMap.html#fetch/2-examples"},{"type":"function","title":"Orderly.SortedMap.get/3","doc":"Get the value for the given `key` in `sorted_map`.\n\nIf `key` is present, the corresponding value is returned. Otherwise,\n`default` is returned. If `default` is not provided, `nil` is returned.","ref":"Orderly.SortedMap.html#get/3"},{"type":"function","title":"Examples - Orderly.SortedMap.get/3","doc":"iex> map = Orderly.SortedMap.new([a: 1])\n    iex> Orderly.SortedMap.get(map, :a)\n    1\n    iex> Orderly.SortedMap.get(map, :b, 2)\n    2","ref":"Orderly.SortedMap.html#get/3-examples"},{"type":"function","title":"Orderly.SortedMap.has_key?/2","doc":"Check if `sorted_map` has the given `key`.","ref":"Orderly.SortedMap.html#has_key?/2"},{"type":"function","title":"Examples - Orderly.SortedMap.has_key?/2","doc":"iex> [a: 1] |> Orderly.SortedMap.new() |> Orderly.SortedMap.has_key?(:a)\n    true","ref":"Orderly.SortedMap.html#has_key?/2-examples"},{"type":"function","title":"Orderly.SortedMap.keys/1","doc":"Return the list of keys in `sorted_map`.\n\nThe keys are returned in key-order.","ref":"Orderly.SortedMap.html#keys/1"},{"type":"function","title":"Examples - Orderly.SortedMap.keys/1","doc":"iex> [b: 2, a: 1] |> Orderly.SortedMap.new() |> Orderly.SortedMap.keys()\n    [:a, :b]\n\n    iex> Orderly.SortedMap.new() |> Orderly.SortedMap.keys()\n    []","ref":"Orderly.SortedMap.html#keys/1-examples"},{"type":"function","title":"Orderly.SortedMap.new/0","doc":"Create an empty map.","ref":"Orderly.SortedMap.html#new/0"},{"type":"function","title":"Examples - Orderly.SortedMap.new/0","doc":"iex> Orderly.SortedMap.new()\n    Orderly.SortedMap.new([])","ref":"Orderly.SortedMap.html#new/0-examples"},{"type":"function","title":"Orderly.SortedMap.new/1","doc":"Create a new map from the given `enumerable`.","ref":"Orderly.SortedMap.html#new/1"},{"type":"function","title":"Examples - Orderly.SortedMap.new/1","doc":"iex> Orderly.SortedMap.new([a: 1, b: 2])\n    Orderly.SortedMap.new([a: 1, b: 2])\n\n    iex> Orderly.SortedMap.new(%{a: 1, b: 2})\n    Orderly.SortedMap.new([a: 1, b: 2])","ref":"Orderly.SortedMap.html#new/1-examples"},{"type":"function","title":"Orderly.SortedMap.pop/3","doc":"Removs the value associated with `key` in `sorted_map` and return the value\nand the updated map.\n\nIf `key` is present in `sorted_map`, it returns `{value, updated_map}` where\n`value` is the value associated with `key` and `updated_map` is the result of\nremoving `key` from `sorted_map`. If key is not present in map,\n`{default, sorted_map}` is returned.","ref":"Orderly.SortedMap.html#pop/3"},{"type":"function","title":"Examples - Orderly.SortedMap.pop/3","doc":"iex> map = Orderly.SortedMap.new([a: 1, b: 2])\n    iex> Orderly.SortedMap.pop(map, :a)\n    {1, Orderly.SortedMap.new([b: 2])}\n    iex> Orderly.SortedMap.pop(map, :c, 3)\n    {3, map}","ref":"Orderly.SortedMap.html#pop/3-examples"},{"type":"function","title":"Orderly.SortedMap.put/3","doc":"Insert `value` under `key` into `sorted_map`.\n\nIf `key` is present, its value is updated to the given `value`. If `key`\nis absent, `key` and `value` are added to `sorted_map`.","ref":"Orderly.SortedMap.html#put/3"},{"type":"function","title":"Examples - Orderly.SortedMap.put/3","doc":"iex> Orderly.SortedMap.new() |> Orderly.SortedMap.put(:a, 1)\n    Orderly.SortedMap.new([a: 1])","ref":"Orderly.SortedMap.html#put/3-examples"},{"type":"function","title":"Orderly.SortedMap.size/1","doc":"Return the number of key-value pairs in `sorted_map`.","ref":"Orderly.SortedMap.html#size/1"},{"type":"function","title":"Examples - Orderly.SortedMap.size/1","doc":"iex> map = Orderly.SortedMap.new([a: 1])\n    iex> Orderly.SortedMap.size(map)\n    1","ref":"Orderly.SortedMap.html#size/1-examples"},{"type":"function","title":"Orderly.SortedMap.smallest/1","doc":"Return the key-value pair with the smallest key in `sorted_map`.\n\nThis returns `{:ok, {key, value}}` if the map is non-empty, and `:error` otherwise.","ref":"Orderly.SortedMap.html#smallest/1"},{"type":"function","title":"Examples - Orderly.SortedMap.smallest/1","doc":"iex> [b: 2, a: 1] |> Orderly.SortedMap.new() |> Orderly.SortedMap.smallest()\n    {:ok, {:a, 1}}\n\n    iex> Orderly.SortedMap.new([]) |> Orderly.SortedMap.smallest()\n    :error","ref":"Orderly.SortedMap.html#smallest/1-examples"},{"type":"function","title":"Orderly.SortedMap.to_list/1","doc":"Convert `sorted_map` into a sorted list of elements.","ref":"Orderly.SortedMap.html#to_list/1"},{"type":"function","title":"Examples - Orderly.SortedMap.to_list/1","doc":"iex> Orderly.SortedMap.new([a: 1, b: 2]) |> Orderly.SortedMap.to_list()\n    [a: 1, b: 2]","ref":"Orderly.SortedMap.html#to_list/1-examples"},{"type":"function","title":"Orderly.SortedMap.to_stream/1","doc":"Create a [`Stream`](https://hexdocs.pm/elixir/Stream.html) from `sorted_map`\nthat emits key-value pairs in key-order starting from the smallest key in\nthe map.\n\nTo generate values lazily, this uses\n[`:gb_trees.iterator/1`](https://www.erlang.org/doc/man/gb_trees#iterator-1) and\n[`:gb_trees.next/1`](https://www.erlang.org/doc/man/gb_trees#next-1).","ref":"Orderly.SortedMap.html#to_stream/1"},{"type":"function","title":"Examples - Orderly.SortedMap.to_stream/1","doc":"iex> map = Orderly.SortedMap.new([b: 2, a: 1, c: 3])\n    iex> stream = Orderly.SortedMap.to_stream(map)\n    iex> stream |> Enum.take(2)\n    [a: 1, b: 2]\n    iex> stream |> Enum.filter(fn {_k, v} -> rem(v, 2) == 0 end)\n    [b: 2]","ref":"Orderly.SortedMap.html#to_stream/1-examples"},{"type":"function","title":"Orderly.SortedMap.to_stream/2","doc":"Create a [`Stream`](https://hexdocs.pm/elixir/Stream.html) from `sorted_map`\nthat emits key-value pairs in key-order starting from the first key in the\nmap greater than or equal to `start_key`.\n\nTo generate values lazily, this uses\n[`:gb_trees.iterator_from/2`](https://www.erlang.org/doc/man/gb_trees#iterator_from-2) and\n[`:gb_trees.next/1`](https://www.erlang.org/doc/man/gb_trees#next-1).","ref":"Orderly.SortedMap.html#to_stream/2"},{"type":"function","title":"Examples - Orderly.SortedMap.to_stream/2","doc":"iex> map = Orderly.SortedMap.new([b: 2, a: 1, c: 3])\n    iex> stream = Orderly.SortedMap.to_stream(map, :b)\n    iex> stream |> Enum.take(2)\n    [b: 2, c: 3]\n    iex> stream |> Enum.filter(fn {_k, v} -> rem(v, 2) != 0 end)\n    [c: 3]","ref":"Orderly.SortedMap.html#to_stream/2-examples"},{"type":"function","title":"Orderly.SortedMap.update/4","doc":"Update the value under the given `key` in `sorted_map` with given function\n`fun`.\n\nIf `key` is present, `fun` is applied to the existing value to obtain the\nupdated value. If `key` is not present, `default` is inserted under `key`.","ref":"Orderly.SortedMap.html#update/4"},{"type":"function","title":"Examples - Orderly.SortedMap.update/4","doc":"iex> map = Orderly.SortedMap.new([a: 1])\n    iex> Orderly.SortedMap.update(map, :a, nil, & &1 + 1)\n    Orderly.SortedMap.new([a: 2])\n    iex> Orderly.SortedMap.update(map, :b, 2, & &1 + 1)\n    Orderly.SortedMap.new([a: 1, b: 2])","ref":"Orderly.SortedMap.html#update/4-examples"},{"type":"function","title":"Orderly.SortedMap.values/1","doc":"Return the list of values in `sorted_map`.\n\nThe values are returned in key-order.","ref":"Orderly.SortedMap.html#values/1"},{"type":"function","title":"Examples - Orderly.SortedMap.values/1","doc":"iex> [b: 2, a: 1] |> Orderly.SortedMap.new() |> Orderly.SortedMap.values()\n    [1, 2]\n\n    iex> Orderly.SortedMap.new() |> Orderly.SortedMap.values()\n    []","ref":"Orderly.SortedMap.html#values/1-examples"},{"type":"type","title":"Orderly.SortedMap.iter/0","doc":"","ref":"Orderly.SortedMap.html#t:iter/0"},{"type":"type","title":"Orderly.SortedMap.key/0","doc":"","ref":"Orderly.SortedMap.html#t:key/0"},{"type":"type","title":"Orderly.SortedMap.t/0","doc":"","ref":"Orderly.SortedMap.html#t:t/0"},{"type":"type","title":"Orderly.SortedMap.t/2","doc":"","ref":"Orderly.SortedMap.html#t:t/2"},{"type":"type","title":"Orderly.SortedMap.value/0","doc":"","ref":"Orderly.SortedMap.html#t:value/0"},{"type":"module","title":"Orderly.SortedSet","doc":"Implementation of a sorted set based on Erlang's\n[`gb_sets`](https://www.erlang.org/doc/man/gb_sets).\n\n`SortedSet` has many of the core functions found in\n[`MapSet`](https://hexdocs.pm/elixir/1.16.2/MapSet.html). The important difference\nbetween `SortedSet` and `MapSet` is that the values in a sorted\nset have a defined order, specifically the\n[Erlang term order](https://www.erlang.org/doc/reference_manual/expressions#term-comparisons).\nFor example:\n\n    set =\n      [2, 1, 3, 1]\n      |> SortedSet.new()\n      |> SortedSet.to_list()\n    #=> [1, 2, 3]\n\nAll functions that involve accessing, inserting, or deleting an element have\n`O(log n)` time complexity.\n\nLike `MapSet`, `SortedSet` is an opaque data structure that does not support\npattern matching.\n\n`SortedSet` implements the `Enumerable` protocol, so that `Enum`\nfunctions can be applied to sorted sets. When applying `Stream` functions\nto a sorted set, it is recommended to first create a stream using\n`SortedSet.to_stream/1` or `SortedSet.to_stream/2`, which adapts the effecient\nlazy iterator pattern provided by `gb_sets`.","ref":"Orderly.SortedSet.html"},{"type":"function","title":"Orderly.SortedSet.delete/2","doc":"Delete `value` from `sorted_set`.\n\nThis returns a set without `value`. If `value` is not present, the original\nset is returned unchanged.","ref":"Orderly.SortedSet.html#delete/2"},{"type":"function","title":"Examples - Orderly.SortedSet.delete/2","doc":"iex> set = Orderly.SortedSet.new([2, 1, 3])\n    iex> Orderly.SortedSet.delete(set, 2)\n    Orderly.SortedSet.new([1, 3])\n    iex> Orderly.SortedSet.delete(set, 4)\n    Orderly.SortedSet.new([1, 2, 3])","ref":"Orderly.SortedSet.html#delete/2-examples"},{"type":"function","title":"Orderly.SortedSet.difference/2","doc":"Obtain a set with the elements of `sorted_set` that are not contained in `sorted_set2`.","ref":"Orderly.SortedSet.html#difference/2"},{"type":"function","title":"Examples - Orderly.SortedSet.difference/2","doc":"iex> set1 = Orderly.SortedSet.new([2, 1, 3])\n    iex> set2 = Orderly.SortedSet.new([1, 2])\n    iex> Orderly.SortedSet.difference(set1, set2) |> Orderly.SortedSet.to_list()\n    [3]","ref":"Orderly.SortedSet.html#difference/2-examples"},{"type":"function","title":"Orderly.SortedSet.equal?/2","doc":"Check if two sorted sets are equal.\n\nThis checks the equality of the list representations.","ref":"Orderly.SortedSet.html#equal?/2"},{"type":"function","title":"Examples - Orderly.SortedSet.equal?/2","doc":"iex> set1 = Orderly.SortedSet.new([2, 1, 3])\n    iex> set2 = Orderly.SortedSet.new([3, 2, 1])\n    iex> Orderly.SortedSet.equal?(set1, set2)","ref":"Orderly.SortedSet.html#equal?/2-examples"},{"type":"function","title":"Orderly.SortedSet.intersection/2","doc":"Obtain a set with elements in both `sorted_set1` and `sorted_set2`.","ref":"Orderly.SortedSet.html#intersection/2"},{"type":"function","title":"Examples - Orderly.SortedSet.intersection/2","doc":"iex> set1 = Orderly.SortedSet.new([2, 1, 3])\n    iex> set2 = Orderly.SortedSet.new([1, 2])\n    iex> Orderly.SortedSet.intersection(set1, set2) |> Orderly.SortedSet.to_list()\n    [1, 2]","ref":"Orderly.SortedSet.html#intersection/2-examples"},{"type":"function","title":"Orderly.SortedSet.member?/2","doc":"Check if `value` is contained in `sorted_set`.","ref":"Orderly.SortedSet.html#member?/2"},{"type":"function","title":"Examples - Orderly.SortedSet.member?/2","doc":"iex> set = Orderly.SortedSet.new([2, 1, 3])\n    iex> Orderly.SortedSet.member?(set, 2)\n    true\n    iex> Orderly.SortedSet.member?(set, 4)\n    false","ref":"Orderly.SortedSet.html#member?/2-examples"},{"type":"function","title":"Orderly.SortedSet.new/0","doc":"Create an empty set.","ref":"Orderly.SortedSet.html#new/0"},{"type":"function","title":"Examples - Orderly.SortedSet.new/0","doc":"iex> Orderly.SortedSet.new()\n    Orderly.SortedSet.new([])","ref":"Orderly.SortedSet.html#new/0-examples"},{"type":"function","title":"Orderly.SortedSet.new/1","doc":"Create a new set from the given `enumerable`.","ref":"Orderly.SortedSet.html#new/1"},{"type":"function","title":"Examples - Orderly.SortedSet.new/1","doc":"iex> Orderly.SortedSet.new([3, 1, 2])\n    Orderly.SortedSet.new([1, 2, 3])\n\n    iex> Orderly.SortedSet.new([{1, 2}, {2, 4}, {1, 3}])\n    Orderly.SortedSet.new([{1, 2}, {1, 3}, {2, 4}])","ref":"Orderly.SortedSet.html#new/1-examples"},{"type":"function","title":"Orderly.SortedSet.put/2","doc":"Insert `value` into `sorted_set`.","ref":"Orderly.SortedSet.html#put/2"},{"type":"function","title":"Examples - Orderly.SortedSet.put/2","doc":"iex> Orderly.SortedSet.new() |> Orderly.SortedSet.put(1)\n    Orderly.SortedSet.new([1])","ref":"Orderly.SortedSet.html#put/2-examples"},{"type":"function","title":"Orderly.SortedSet.size/1","doc":"Return the number of elements in `sorted_set`.","ref":"Orderly.SortedSet.html#size/1"},{"type":"function","title":"Examples - Orderly.SortedSet.size/1","doc":"iex> Orderly.SortedSet.new([2, 1, 3]) |> Orderly.SortedSet.size()\n    3","ref":"Orderly.SortedSet.html#size/1-examples"},{"type":"function","title":"Orderly.SortedSet.smallest/1","doc":"Return the element with the smallest value in `sorted_set`.\n\nThis returns `{:ok, value}` if the set is non-empty, and `:error` otherwise.","ref":"Orderly.SortedSet.html#smallest/1"},{"type":"function","title":"Examples - Orderly.SortedSet.smallest/1","doc":"iex> Orderly.SortedSet.new([2, 1, 3]) |> Orderly.SortedSet.smallest()\n    {:ok, 1}\n\n    iex> Orderly.SortedSet.new([]) |> Orderly.SortedSet.smallest()\n    :error","ref":"Orderly.SortedSet.html#smallest/1-examples"},{"type":"function","title":"Orderly.SortedSet.subset?/2","doc":"Checks if all of the elements in `sorted_set1` are contained in `sorted_set2`.","ref":"Orderly.SortedSet.html#subset?/2"},{"type":"function","title":"Examples - Orderly.SortedSet.subset?/2","doc":"iex> set1 = Orderly.SortedSet.new([2, 1, 3])\n    iex> set2 = Orderly.SortedSet.new([1, 2])\n    iex> Orderly.SortedSet.subset?(set2, set1)\n    true","ref":"Orderly.SortedSet.html#subset?/2-examples"},{"type":"function","title":"Orderly.SortedSet.to_list/1","doc":"Convert `sorted_set` into a sorted list of elements.","ref":"Orderly.SortedSet.html#to_list/1"},{"type":"function","title":"Examples - Orderly.SortedSet.to_list/1","doc":"iex> Orderly.SortedSet.new([2, 1, 3]) |> Orderly.SortedSet.to_list()\n    [1, 2, 3]","ref":"Orderly.SortedSet.html#to_list/1-examples"},{"type":"function","title":"Orderly.SortedSet.to_stream/1","doc":"Create a [`Stream`](https://hexdocs.pm/elixir/Stream.html) from `sorted_set`\nthat emits elements in order starting from the smallest element in the set.\n\nTo generate values lazily, this uses\n[`:gb_sets.iterator/1`](https://www.erlang.org/doc/man/gb_sets#iterator-1) and\n[`:gb_sets.next/1`](https://www.erlang.org/doc/man/gb_sets#next-1).","ref":"Orderly.SortedSet.html#to_stream/1"},{"type":"function","title":"Examples - Orderly.SortedSet.to_stream/1","doc":"iex> set = Orderly.SortedSet.new([2, 1, 3, 5, 4])\n    iex> stream = Orderly.SortedSet.to_stream(set)\n    iex> stream |> Enum.take(3)\n    [1, 2, 3]\n    iex> stream |> Enum.take_while(& &1 <= 4)\n    [1, 2, 3, 4]","ref":"Orderly.SortedSet.html#to_stream/1-examples"},{"type":"function","title":"Orderly.SortedSet.to_stream/2","doc":"Create a [`Stream`](https://hexdocs.pm/elixir/Stream.html) from `sorted_set`\nthat emits elements in order starting from the first element in the set\ngreater than or equal to `start_value`.\n\nTo generate values lazily, this uses\n[`:gb_sets.iterator_from/2`](https://www.erlang.org/doc/man/gb_sets#iterator_from-2) and\n[`:gb_sets.next/1`](https://www.erlang.org/doc/man/gb_sets#next-1).","ref":"Orderly.SortedSet.html#to_stream/2"},{"type":"function","title":"Examples - Orderly.SortedSet.to_stream/2","doc":"iex> set = Orderly.SortedSet.new([2, 1, 3, 5, 4])\n    iex> stream = Orderly.SortedSet.to_stream(set, 2)\n    iex> stream |> Enum.take(3)\n    [2, 3, 4]\n    iex> stream |> Enum.take_while(& &1 <= 3)\n    [2, 3]","ref":"Orderly.SortedSet.html#to_stream/2-examples"},{"type":"function","title":"Orderly.SortedSet.union/2","doc":"Obtain a set that contains all elements of `sorted_set1` and `sorted_set2`.","ref":"Orderly.SortedSet.html#union/2"},{"type":"function","title":"Examples - Orderly.SortedSet.union/2","doc":"iex> set1 = Orderly.SortedSet.new([2, 1, 3])\n    iex> set2 = Orderly.SortedSet.new([4, 5])\n    iex> Orderly.SortedSet.union(set1, set2) |> Orderly.SortedSet.to_list()\n    [1, 2, 3, 4, 5]","ref":"Orderly.SortedSet.html#union/2-examples"},{"type":"type","title":"Orderly.SortedSet.iter/0","doc":"","ref":"Orderly.SortedSet.html#t:iter/0"},{"type":"type","title":"Orderly.SortedSet.set/1","doc":"","ref":"Orderly.SortedSet.html#t:set/1"},{"type":"type","title":"Orderly.SortedSet.t/0","doc":"","ref":"Orderly.SortedSet.html#t:t/0"},{"type":"type","title":"Orderly.SortedSet.t/1","doc":"","ref":"Orderly.SortedSet.html#t:t/1"},{"type":"type","title":"Orderly.SortedSet.value/0","doc":"","ref":"Orderly.SortedSet.html#t:value/0"},{"type":"extras","title":"Orderly","doc":"# Orderly\n\nSorted set and sorted map implementations based on Erlang's \n[`gb_sets`](https://www.erlang.org/doc/man/gb_sets) and \n[`gb_trees`](https://www.erlang.org/doc/man/gb_trees).\n\nSee the modules `Orderly.SortedMap` and `Orderly.SortedSet` for detailed documentation.","ref":"readme.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}